@@ -18,7 +18,7 @@
 #ifndef FILEEXISTSDIALOG_H
 #define FILEEXISTSDIALOG_H
 
-#include <ntqwidget.h>
+#include <tqwidget.h>
 #include "Q_fileexistsdialog.h"
 
 /**
